<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'pleased_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','pleased-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'pleased-pro' ),
	'panel'             => 'pleased_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'pleased-pro' ),
	'section'           => 'pleased_pro_blog_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[blog_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[blog_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_blog_section',
	'active_callback' 	=> 'pleased_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[blog_sub_title]', array(
		'selector'            => '#latest-blog .section-header span.section-subtitle',
		'settings'            => 'pleased_pro_theme_options[blog_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_blog_sub_title_partial',
    ) );
}

// blog title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_blog_section',
	'active_callback' 	=> 'pleased_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[blog_title]', array(
		'selector'            => '#latest-blog .section-header h2.section-title',
		'settings'            => 'pleased_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_blog_title_partial',
    ) );
}

// Blog content type control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'pleased_pro_sanitize_select',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pleased-pro' ),
	'section'           => 'pleased_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pleased_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'pleased-pro' ),
		'post' 		=> esc_html__( 'Post', 'pleased-pro' ),
		'category' 	=> esc_html__( 'Category', 'pleased-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'pleased-pro' ),
	),
) );

for ( $i = 1; $i <= 3; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_blog_section',
		'choices'			=> pleased_pro_page_choices(),
		'active_callback'	=> 'pleased_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'pleased_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pleased_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pleased_Pro_Dropdown_Chooser( $wp_customize, 'pleased_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'pleased-pro' ), $i ),
		'section'           => 'pleased_pro_blog_section',
		'choices'			=> pleased_pro_post_choices(),
		'active_callback'	=> 'pleased_pro_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pleased_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pleased-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'pleased-pro' ),
	'section'           => 'pleased_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'pleased_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Category_Control( $wp_customize,'pleased_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'pleased-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'pleased-pro' ),
	'section'           => 'pleased_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'pleased_pro_is_blog_section_content_recent_enable'
) ) );

// blog btn title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_blog_section',
	'active_callback' 	=> 'pleased_pro_is_blog_section_enable',
	'type'				=> 'text',
) );
